import logging

import boto3
import click

import relaunch_instance as ri
import relaunch_instance.relaunch as relaunch


@click.command()
@click.option("--instance-id", "-i", required=True, type=str, help="Instance ID")
@click.option(
    "--region",
    "-r",
    required=True,
    type=str,
    help="Region string in long format",
)
@click.option(
    "--ami-id",
    "-a",
    type=str,
    help="AMI to use for new instances instead of creating a new one",
)
@click.option(
    "--instance-type",
    help="Override instance type",
)
@click.option(
    "--private-ip",
    help="Override instance type",
)
@click.option(
    "--root-volume-size",
    type=int,
    help="Size of new instances root volume in GB. If not set, root volume will be increased based on instance type to accomodate RAM for hibernation",
)
@click.option(
    "--encrypt-root-volume",
    type=bool,
    is_flag=True,
    help="Encrypt root volume",
)
@click.option(
    "--kms-key-id",
    type=int,
    help="KMS key ID to use for root volume encryption. AWS EBS default key used if not specified",
)
@click.option(
    "--enable-hibernation",
    type=bool,
    is_flag=True,
    help="Encrypts root volume and increases root volume size to accomodate RAM.",
)
@click.option("--settings-input", type=str, help="Instance settings input file")
@click.option(
    "--dump-settings",
    is_flag=True,
    help="Dump settings to file by name instead of running instance",
)
@click.option(
    "--settings-output",
    type=str,
    default=ri.SETTINGS_FILE,
    help="Output file when dumping settings",
)
@click.option("--launch-template", is_flag=True, help="Generate launch template")
@click.option(
    "--log-level",
    "-l",
    help="Log level as string",
    default="INFO",
    type=click.Choice(["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"]),
)
@click.option("--yes", is_flag=True, help="Assume yes to all prompts")
def main(
    instance_id,
    region,
    **kwargs,
):
    log = logging.getLogger(__name__)
    logging.basicConfig(level=kwargs["log_level"])
    client = boto3.client("ec2", region)
    resource = boto3.resource("ec2", region)
    inference_client = boto3.client("elastic-inference", region)

    if kwargs["settings_input"]:
        if kwargs["dump_settings"]:
            log.error("Cannot use --settings-input and --dump-settings")
            return 1
        if (
            kwargs["ami_id"]
            or kwargs["instance_type"]
            or kwargs["private_ip"]
            or kwargs["root_volume_size"]
            or kwargs["kms_key_id"]
            or kwargs["encrypt_root_volume"]
        ):
            log.error(
                "Cannot use --settings-input with --ami-id, --instance-type, --private-ip, --root-volume-size, or --kms-key-id"
            )
            log.info("Please set these values in the settings file")
            return 1

    relaunch.relaunch(instance_id, region, client, resource, inference_client, **kwargs)
